==> power_widget-0.0.14.tar.gz: lib/widgets/stateful/PowerStatefulCardView.dart <==
import 'package:flutter/widgets.dart';
import 'package:power_widget/serializable/WidgetSerializableModel.dart';
import 'package:power_widget/widgets/PowerCardView.dart';
import 'package:power_widget/widgets/stateful/ModularizedStatefulWidget.dart';

abstract class PowerStatefulCardView extends ModularizedStatefulWidget with PowerCardView {
  PowerStatefulCardViewState state;

  @override
  State<StatefulWidget> createState() {
    // TODO: implement createState
    state = PowerStatefulCardViewState(getSize(), provideCardViewPainter(), provideChildrenStack());
    return state;
  }

  @override
  WidgetSerializableModel getWidgetSerializableModel() {
    // TODO: implement getWidgetSerializableModel
    return null;
  }

  void setChildrenStack(Stack stack) {
    this.state.setChildrenStack(stack);
  }

  void notifyWidgetUpdate() {
    state.notifyWidgetUpdate();
  }
}

class PowerStatefulCardViewState extends State<PowerStatefulCardView> {
  CustomPainter customPainter;
  Stack childrenStack;
  Size size;
  PowerCardView powerCardView;

  PowerStatefulCardViewState(this.size, this.customPainter, this.childrenStack);

  void setChildrenStack(Stack stack) {
    this.childrenStack = stack;
  }

  void notifyWidgetUpdate() {
    setState(() {});
  }

  @override
  Widget build(BuildContext context) {
    // TODO: implement build
    return Center(
      child: CustomPaint(
        child: this.childrenStack,
        size: size,
        painter: this.customPainter,
      ),
    );
  }
}

==> power_widget-0.0.23.tar.gz: lib/widgets/stateful/PowerStatefulCardView.dart <==
import 'package:flutter/widgets.dart';
import 'package:power_widget/serializable/WidgetSerializableModel.dart';
import 'package:power_widget/widgets/PowerCardView.dart';
import 'package:power_widget/widgets/stateful/ModularizedStatefulWidget.dart';

abstract class PowerStatefulCardView extends ModularizedStatefulWidget with PowerCardView {
  PowerStatefulCardViewState state;

  @override
  State<StatefulWidget> createState() {
    // TODO: implement createState
    state = PowerStatefulCardViewState(getSize(), provideCardViewPainter(), provideChildrenStack());
    return state;
  }

  @override
  WidgetSerializableModel getWidgetSerializableModel() {
    // TODO: implement getWidgetSerializableModel
    return null;
  }

  void notifyWidgetUpdate() {
    Stack stack = provideChildrenStack();
    state.setChildrenStack(stack);
    state.notifyWidgetUpdate();
  }
}

class PowerStatefulCardViewState extends State<PowerStatefulCardView> {
  CustomPainter customPainter;
  Stack childrenStack;
  Size size;
  PowerCardView powerCardView;

  PowerStatefulCardViewState(this.size, this.customPainter, this.childrenStack);

  void setChildrenStack(Stack stack) {
    this.childrenStack = stack;
  }

  void notifyWidgetUpdate() {
    setState(() {});
  }

  @override
  Widget build(BuildContext context) {
    // TODO: implement build
    return Center(
      child: CustomPaint(
        child: this.childrenStack,
        size: size,
        painter: this.customPainter,
      ),
    );
  }
}
